@@ -1,4 +1,4 @@
-﻿#!/usr/bin/python
+#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 import os, re
@@ -6,8 +6,8 @@ from urlparse import urlparse
 from PyQt4 import QtCore
 from PyQt4.QtNetwork import QNetworkRequest, QNetworkAccessManager, QNetworkProxy, QNetworkReply
 import HTMLParser
-from DebugLog import DebugLog, DebugFile
-from RideModel import RideModel, Ride
+from utils.DebugLog import DebugLog, DebugFile
+from model.RideModel import RideModel, Ride
 
 class Extractor(QtCore.QObject):
    def __init__(self, id):
