@@ -4,9 +4,9 @@
 from PyQt4.QtNetwork import QNetworkRequest
 import HTMLParser,  re
 import ConfigParser
-from htmlTools import htmlTools
+from utils.htmlTools import htmlTools
 from Extractor import Extractor
-from DebugLog import DebugLog, DebugFile
+from utils.DebugLog import DebugLog, DebugFile
 
 class TableParserMetro(Extractor, HTMLParser.HTMLParser):
 
