@@ -1,18 +1,19 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import time
+import time, os
 from PyQt4 import QtGui, QtCore
 from PyQt4.QtCore import Qt
-from DebugLog import DebugLog
-from RideModel import RideModel
-from CircleProgress import CircleProgress
+from utils.DebugLog import DebugLog, getScriptPath
+from model.RideModel import RideModel
+from utils.CircleProgress import CircleProgress
 
 class RideView(QtGui.QWidget):
    def __init__(self, model, parent):
       DebugLog("RideView::__init__")
       super(QtGui.QWidget, self).__init__(parent)
 
+      self.iconsPath = os.path.join(os.path.dirname(getScriptPath()), 'icons')
       self.parent = parent
       self.anims = []
       self.model = model
@@ -25,6 +26,9 @@ class RideView(QtGui.QWidget):
       self.animate.finished.connect(self.AnimateFinished)
       self.animate.setDuration(333)
 
+   def IconPath(self, str):
+      return os.path.join(self.iconsPath, str)
+      
    def PrepareWidget(self):
       DebugLog("RideView::PrepareWidget")
       self.layout = QtGui.QGridLayout(self)
@@ -93,7 +97,7 @@ class RideView(QtGui.QWidget):
       iconT.setMinimumHeight(48)
       iconT.setFixedWidth(44)
       iconT.setStyleSheet("background: #fff; margin: 0; padding: 0; padding-left: 3px ")
-      iconPath = 'icons/tec/%dx%d/%s.png'%(s, s, t)
+      iconPath = self.IconPath('tec/%dx%d/%s.png'%(s, s, t))
       iconT.setPixmap( QtGui.QPixmap(iconPath) )
       iconLayout.addWidget( iconT, Qt.AlignCenter )
 
@@ -103,7 +107,7 @@ class RideView(QtGui.QWidget):
       iconL.setMinimumHeight(48)
       iconL.setFixedWidth(44)
       iconL.setStyleSheet("background: #fff; margin: 0; padding: 0; padding-left: 3px ")
-      iconPath = 'icons/tec/%dx%d/%s%s.png'%(s, s, t, l)
+      iconPath = self.IconPath('tec/%dx%d/%s%s.png'%(s, s, t, l))
       iconL.setPixmap( QtGui.QPixmap(iconPath) )
       iconLayout.addWidget( iconL, Qt.AlignCenter )
 
@@ -196,7 +200,7 @@ class RideView(QtGui.QWidget):
    def SetInfo(self, stype, text):
       if stype=='ERROR':
          self.progress.setStyleSheet("color: #fff; background: #f00; padding:5px; margin:0; ")
-         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap('icons/error.png').scaled(32,32) ))
+         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap(self.IconPath('error.png')).scaled(32,32) ))
          self.infoButton.show()
 
       elif stype=='PROGRESS':
@@ -204,7 +208,7 @@ class RideView(QtGui.QWidget):
 
       elif stype=='WARNING':
          self.progress.setStyleSheet("color: #000; background: #FFCD00; padding:5px; margin:0; ")
-         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap('icons/warning.png').scaled(32,32) ))
+         self.infoButton.setIcon(QtGui.QIcon( QtGui.QPixmap(self.IconPath('warning.png')).scaled(32,32) ))
          self.infoButton.show()
 
       self.progress.setText(text)
